More switch reformatting.
[open-adventure.git] / misc.c
diff --git a/misc.c b/misc.c
index baa0d56c70c7a69f05f68c0f894cfe1c22bb651a..1bc963b0d465ca07d99108b0570e363a36cde481 100644 (file)
--- a/misc.c
+++ b/misc.c
@@ -1,3 +1,4 @@
+#include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include "main.h"
@@ -14,11 +15,11 @@ void fSPEAK(long N) {
 long BLANK, CASE, I, K, L, NEG, NPARMS, PARM, PRMTYP, STATE;
 
 /*  Print the message which starts at LINES(N).  Precede it with a blank line
*  unless BLKLIN is false. */
 
 
        if(N == 0)return;
-       BLANK=BLKLIN;
+       BLANK=game.blklin;
        K=N;
        NPARMS=1;
 L10:   L=IABS(LINES[K])-1;
@@ -171,20 +172,21 @@ void fSETPRM(long FIRST, long P1, long P2) {
 #define WORD1X (*wORD1X)
 #define WORD2 (*wORD2)
 #define WORD2X (*wORD2X)
-void fGETIN(long *wORD1, long *wORD1X, long *wORD2, long *wORD2X) {
+void fGETIN(FILE *input, long *wORD1, long *wORD1X, long *wORD2, long *wORD2X) {
 long JUNK;
 
-/*  Get a command from the adventurer.  snarf out the first word, pad it with
+/*  Get a command from the adventurer.  Snarf out the first word, pad it with
  *  blanks, and return it in WORD1.  Chars 6 thru 10 are returned in WORD1X, in
  *  case we need to print out the whole word in an error message.  Any number of
  *  blanks may follow the word.  If a second word appears, it is returned in
  *  WORD2 (chars 6 thru 10 in WORD2X), else WORD2 is -1. */
 
 
-L10:   if(BLKLIN)TYPE0();
-       MAPLIN(false);
+L10:   if(game.blklin)TYPE0();
+       MAPLIN(input);
+       if(input == stdin && feof(stdin)) score(1);
        WORD1=GETTXT(true,true,true,0);
-       if(BLKLIN && WORD1 < 0) goto L10;
+       if(game.blklin && WORD1 < 0) goto L10;
        WORD1X=GETTXT(false,true,true,0);
 L12:   JUNK=GETTXT(false,true,true,0);
        if(JUNK > 0) goto L12;
@@ -203,9 +205,9 @@ L22:        JUNK=GETTXT(false,true,true,0);
 #undef WORD1X
 #undef WORD2
 #undef WORD2X
-#define GETIN(WORD1,WORD1X,WORD2,WORD2X) fGETIN(&WORD1,&WORD1X,&WORD2,&WORD2X)
+#define GETIN(SRC,WORD1,WORD1X,WORD2,WORD2X) fGETIN(SRC,&WORD1,&WORD1X,&WORD2,&WORD2X)
 #undef YES
-long fYES(long X, long Y, long Z) {
+long fYES(FILE *input, long X, long Y, long Z) {
 
 long YES, REPLY, JUNK1, JUNK2, JUNK3;
 
@@ -213,7 +215,7 @@ long YES, REPLY, JUNK1, JUNK2, JUNK3;
  *  if no, print Z and return false. */
 
 L1:    RSPEAK(X);
-       GETIN(REPLY,JUNK1,JUNK2,JUNK3);
+       GETIN(input, REPLY,JUNK1,JUNK2,JUNK3);
        if(REPLY == MAKEWD(250519) || REPLY == MAKEWD(25)) goto L10;
        if(REPLY == MAKEWD(1415) || REPLY == MAKEWD(14)) goto L20;
        RSPEAK(185);
@@ -241,7 +243,7 @@ L20:        YES=false;
 
 #define YES(X,Y,Z) fYES(X,Y,Z)
 #undef GETNUM
-long fGETNUM(long K) {
+long fGETNUM(FILE *source) {
 long DIGIT, GETNUM, SIGN;
 
 /*  Obtain the next integer from an input line.  If K>0, we first read a
@@ -251,7 +253,7 @@ long DIGIT, GETNUM, SIGN;
  *  character (not a digit, hyphen, or blank), we return 0. */
 
 
-       if(K != 0)MAPLIN(K > 0);
+       if(source != NULL)MAPLIN(source);
        GETNUM=0;
 L10:   if(LNPOSN > LNLENG)return(GETNUM);
        if(INLINE[LNPOSN] != 0) goto L20;
@@ -648,13 +650,13 @@ long TEMP;
 
 /*  Start toting an object, removing it from the list of things at its former
  *  location.  Incr holdng unless it was already being toted.  If OBJECT>100
*  (moving "fixed" second loc), don't change PLACE or HOLDNG. */
 
 
        if(OBJECT > 100) goto L5;
        if(PLACE[OBJECT] == -1)return;
        PLACE[OBJECT]= -1;
-       HOLDNG=HOLDNG+1;
+       game.holdng=game.holdng+1;
 L5:    if(ATLOC[WHERE] != OBJECT) goto L6;
        ATLOC[WHERE]=LINK[OBJECT];
        return;
@@ -674,11 +676,11 @@ void fDROP(long OBJECT, long WHERE) {
 ;
 
 /*  Place an object at a given loc, prefixing it onto the ATLOC list.  Decr
*  HOLDNG if the object was being toted. */
 
 
        if(OBJECT > 100) goto L1;
-       if(PLACE[OBJECT] == -1)HOLDNG=HOLDNG-1;
+       if(PLACE[OBJECT] == -1)game.holdng=game.holdng-1;
        PLACE[OBJECT]=WHERE;
         goto L2;
 L1:    {long x = OBJECT-100; FIXED[x]=WHERE;}
@@ -701,7 +703,7 @@ long ATDWRF, I;
 
 
        ATDWRF=0;
-       if(DFLAG < 2)return(ATDWRF);
+       if(game.dflag < 2)return(ATDWRF);
        ATDWRF= -1;
        for (I=1; I<=5; I++) {
        if(DLOC[I] == WHERE) goto L2;
@@ -853,11 +855,11 @@ void fBUG(long NUM) {
 
 #define BUG(NUM) fBUG(NUM)
 #undef MAPLIN
-void fMAPLIN(long FIL) {
-long I, VAL; static FILE *OPENED = NULL;
+void fMAPLIN(FILE *OPENED) {
+long I, VAL;
 
/*  Read a line of input, either from a file (if FIL=true) or from the
*  keyboard, translate the chars to integers in the range 0-126 and store
  *  them in the common array "INLINE".  Integer values are as follows:
  *     0   = space [ASCII CODE 40 octal, 32 decimal]
  *    1-2  = !" [ASCII 41-42 octal, 33-34 decimal]
@@ -879,42 +881,34 @@ long I, VAL; static FILE *OPENED = NULL;
  *  This procedure may use the map1,map2 arrays to maintain static data for
  *  the mapping.  MAP2(1) is set to 0 when the program starts
  *  and is not changed thereafter unless the routines on this page choose
- *  to do so.
- *
- *  Note that MAPLIN is expected to open the file the first time it is
- *  asked to read a line from it.  that is, there is no other place where
- *  the data file is opened. */
-
+ *  to do so. */
 
        if(MAP2[1] == 0)MPINIT();
 
-       if(FIL) goto L15;
-       IGNORE(fgets(INLINE+1, sizeof(INLINE)-1, stdin));
-       if(feof(stdin)) score(1);
-        goto L20;
-
-L15:   if(!OPENED){
-               OPENED=fopen("adventure.text","r" /* NOT binary */);
-               if(!OPENED){printf("Can't read adventure.text!\n"); exit(0);}
+       if (!oldstyle && isatty(0))
+           fputs("> ", stdout);
+       IGNORE(fgets(INLINE+1,sizeof(INLINE)-1,OPENED));
+       if (feof(OPENED)) {
+               if (logfp)
+                       fclose(logfp);
+       } else {
+               if (logfp)
+                       IGNORE(fputs(INLINE+1, logfp));
+               else if (!isatty(0)) {
+                       IGNORE(fputs("> ", stdout));
+                       IGNORE(fputs(INLINE+1, stdout));
                }
-        IGNORE(fgets(INLINE+1,sizeof(INLINE)-1,OPENED));
-
-L20:   LNLENG=0;
-       for (I=1; I<=sizeof(INLINE) && INLINE[I]!=0; I++) {
-       VAL=INLINE[I]+1;
-       INLINE[I]=MAP1[VAL];
-       if(INLINE[I] != 0)LNLENG=I;
-       } /* end loop */
-       LNPOSN=1;
-       if(FIL && LNLENG == 0) goto L15;
-/*  Above is to get around an F40 compiler bug wherein it reads a blank
- *  line whenever a crlf is broken across a record boundary. */
-       return;
+               LNLENG=0;
+               for (I=1; I<=sizeof(INLINE) && INLINE[I]!=0; I++) {
+               VAL=INLINE[I]+1;
+               INLINE[I]=MAP1[VAL];
+               if(INLINE[I] != 0)LNLENG=I;
+               } /* end loop */
+               LNPOSN=1;
+       }
 }
-
-
-
 #define MAPLIN(FIL) fMAPLIN(FIL)
+
 #undef TYPE
 void fTYPE(void) {
 long I, VAL;
@@ -14,11 +15,11 @@ void fSPEAK(long N) {
 
 /*  Print the message which starts at LINES(N).  Precede it with a blank line
- *  unless BLKLIN is false. */
+ *  unless game.blklin is false. */
 
 
@@ -648,13 +650,13 @@ long TEMP;
 /*  Start toting an object, removing it from the list of things at its former
  *  location.  Incr holdng unless it was already being toted.  If OBJECT>100
- *  (moving "fixed" second loc), don't change PLACE or HOLDNG. */
+ *  (moving "fixed" second loc), don't change PLACE or game.holdng. */
 
 
@@ -674,11 +676,11 @@ void fDROP(long OBJECT, long WHERE) {
 
 /*  Place an object at a given loc, prefixing it onto the ATLOC list.  Decr
- *  HOLDNG if the object was being toted. */
+ *  game.holdng if the object was being toted. */
 
 
@@ -853,11 +855,11 @@ void fBUG(long NUM) {
 
-/*  Read a line of input, either from a file (if FIL=true) or from the
- *  keyboard, translate the chars to integers in the range 0-126 and store
+/*  Read a line of input, from the specified input source,
+ *  translate the chars to integers in the range 0-126 and store
  *  them in the common array "INLINE".  Integer values are as follows:
  *     0   = space [ASCII CODE 40 octal, 32 decimal]